import React from 'react';
import { CurrencyDollarIcon } from '@heroicons/react/24/outline';
import { type Asset } from '../../api';

interface AssetsComponentProps {
  assets: Asset[] | null;
  isLoading: boolean;
}

const AssetsComponent: React.FC<AssetsComponentProps> = ({ assets, isLoading }) => {
  const formatCurrency = (value: number) => {
    return new Intl.NumberFormat('pt-BR', {
      style: 'currency',
      currency: 'BRL'
    }).format(value);
  };

  return (
    <div className="bg-white/95 backdrop-blur-sm rounded-xl shadow-lg hover:shadow-xl transform hover:scale-[1.02] transition-all duration-200 p-6">
      <div className="flex items-center mb-6">
        <CurrencyDollarIcon className="h-8 w-8 text-purple-600 mr-3" />
        <h2 className="text-2xl font-bold text-gray-900">Patrimônio Declarado</h2>
      </div>

      {isLoading ? (
        <div className="flex items-center justify-center h-32">
          <div className="animate-spin rounded-full h-8 w-8 border-4 border-purple-600 border-t-transparent"></div>
        </div>
      ) : assets && assets.length > 0 ? (
        <>
          <div className="overflow-x-auto">
            <table className="w-full table-auto">
              <thead>
                <tr className="border-b border-gray-200">
                  <th className="text-left py-3 px-2 font-semibold text-gray-700">Ano</th>
                  <th className="text-left py-3 px-2 font-semibold text-gray-700">Tipo</th>
                  <th className="text-left py-3 px-2 font-semibold text-gray-700">Descrição</th>
                  <th className="text-right py-3 px-2 font-semibold text-gray-700">Valor</th>
                </tr>
              </thead>
              <tbody>
                {assets.map((asset: Asset, index: number) => (
                  <tr key={`${asset.idCandidato}-${asset.ano}-${index}`} className="border-b border-gray-100 hover:bg-gray-50 transition-colors">
                    <td className="py-3 px-2 text-gray-900">{asset.ano}</td>
                    <td className="py-3 px-2 text-gray-900">{asset.tipoBem}</td>
                    <td className="py-3 px-2 text-gray-900">{asset.descricao}</td>
                    <td className="py-3 px-2 text-right text-gray-900 font-medium">
                      {formatCurrency(asset.valor)}
                    </td>
                  </tr>
                ))}
              </tbody>
            </table>
          </div>
          
          {/* Total Assets */}
          <div className="mt-4 pt-4 border-t border-gray-200">
            <div className="flex justify-between items-center">
              <span className="text-lg font-semibold text-gray-700">Total Declarado:</span>
              <span className="text-xl font-bold text-purple-600">
                {formatCurrency(assets.reduce((total, asset) => total + asset.valor, 0))}
              </span>
            </div>
          </div>
        </>
      ) : (
        <div className="text-center text-gray-500 py-8">
          Nenhum patrimônio declarado encontrado
        </div>
      )}
    </div>
  );
};

export default AssetsComponent;
